@@ -1,5 +1,4 @@
 package Template::Sandbox::Library;
-# ABSTRACT: Base library object for Template::Sandbox functions.
 
 use strict;
 use warnings;
@@ -13,7 +12,7 @@ my %function_tags    = ();
 
 BEGIN
 {
-    $Template::Sandbox::Library::VERSION = '1.04_01';
+    $Template::Sandbox::Library::VERSION = '1.01';
 }
 
 sub import
@@ -131,10 +130,6 @@ __END__
 
 Template::Sandbox::Library - Base library object for Template::Sandbox functions.
 
-=head1 VERSION
-
-version 1.04_01
-
 =head1 SYNOPSIS
 
   package MyApp::TemplateMaths;
@@ -313,6 +308,7 @@ You can find documentation for this module with the perldoc command.
 
     perldoc Template::Sandbox::Library
 
+
 You can also look for information at:
 
 =over 4
@@ -335,15 +331,17 @@ L<http://search.cpan.org/dist/Template-Sandbox>
 
 =back
 
-=head1 AUTHOR
+=head1 AUTHORS
 
-Sam Graham <libtemplate-sandbox-perl BLAHBLAH illusori.co.uk>
+Original author: Sam Graham <libtemplate-sandbox-perl BLAHBLAH illusori.co.uk>
 
-=head1 COPYRIGHT AND LICENSE
+Last author:     $Author: illusori $
 
-This software is copyright (c) 2005-2010 by Sam Graham <libtemplate-sandbox-perl BLAHBLAH illusori.co.uk>.
+=head1 COPYRIGHT & LICENSE
 
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
+Copyright 2005-2009 Sam Graham, all rights reserved.
+
+This library is free software; you can redistribute it and/or modify it
+under the same terms as Perl itself.
 
 =cut
