@@ -1,5 +1,4 @@
 package Template::Sandbox::NumberFunctions;
-# ABSTRACT: Basic number functions library for Template::Sandbox.
 
 use strict;
 use warnings;
@@ -8,7 +7,7 @@ use base 'Template::Sandbox::Library';
 
 use Template::Sandbox qw/:function_sugar/;
 
-$Template::Sandbox::NumberFunctions::VERSION = '1.04_01';
+$Template::Sandbox::NumberFunctions::VERSION = '1.01';
 
 #  From perlfaq5: add thousands-commas to number.
 #  Yes it doesn't respect locale.
@@ -76,10 +75,6 @@ __END__
 
 Template::Sandbox::NumberFunctions - Basic number functions library for Template::Sandbox.
 
-=head1 VERSION
-
-version 1.04_01
-
 =head1 SYNOPSIS
 
   use Template::Sandbox::NumberFunctions qw/:all/;
@@ -203,6 +198,7 @@ You can find documentation for this module with the perldoc command.
 
     perldoc Template::Sandbox::NumberFunctions
 
+
 You can also look for information at:
 
 =over 4
@@ -225,15 +221,17 @@ L<http://search.cpan.org/dist/Template-Sandbox>
 
 =back
 
-=head1 AUTHOR
+=head1 AUTHORS
 
-Sam Graham <libtemplate-sandbox-perl BLAHBLAH illusori.co.uk>
+Original author: Sam Graham <libtemplate-sandbox-perl BLAHBLAH illusori.co.uk>
 
-=head1 COPYRIGHT AND LICENSE
+Last author:     $Author: illusori $
 
-This software is copyright (c) 2005-2010 by Sam Graham <libtemplate-sandbox-perl BLAHBLAH illusori.co.uk>.
+=head1 COPYRIGHT & LICENSE
 
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
+Copyright 2005-2009 Sam Graham, all rights reserved.
+
+This library is free software; you can redistribute it and/or modify it
+under the same terms as Perl itself.
 
 =cut
