@@ -1,5 +1,4 @@
 package Template::Sandbox::StringFunctions;
-# ABSTRACT: Basic string functions library for Template::Sandbox.
 
 use strict;
 use warnings;
@@ -8,7 +7,7 @@ use base 'Template::Sandbox::Library';
 
 use Template::Sandbox qw/:function_sugar/;
 
-$Template::Sandbox::StringFunctions::VERSION = '1.04_01';
+$Template::Sandbox::StringFunctions::VERSION = '1.01';
 
 __PACKAGE__->set_library_functions(
     lc      => ( one_arg sub { lc( $_[ 0 ] ) } ),
@@ -35,10 +34,6 @@ __END__
 
 Template::Sandbox::StringFunctions - Basic string functions library for Template::Sandbox.
 
-=head1 VERSION
-
-version 1.04_01
-
 =head1 SYNOPSIS
 
   use Template::Sandbox::StringFunctions qw/:all/;
@@ -117,6 +112,7 @@ You can find documentation for this module with the perldoc command.
 
     perldoc Template::Sandbox::StringFunctions
 
+
 You can also look for information at:
 
 =over 4
@@ -139,15 +135,17 @@ L<http://search.cpan.org/dist/Template-Sandbox>
 
 =back
 
-=head1 AUTHOR
+=head1 AUTHORS
 
-Sam Graham <libtemplate-sandbox-perl BLAHBLAH illusori.co.uk>
+Original author: Sam Graham <libtemplate-sandbox-perl BLAHBLAH illusori.co.uk>
 
-=head1 COPYRIGHT AND LICENSE
+Last author:     $Author: illusori $
 
-This software is copyright (c) 2005-2010 by Sam Graham <libtemplate-sandbox-perl BLAHBLAH illusori.co.uk>.
+=head1 COPYRIGHT & LICENSE
 
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
+Copyright 2005-2009 Sam Graham, all rights reserved.
+
+This library is free software; you can redistribute it and/or modify it
+under the same terms as Perl itself.
 
 =cut
